XprinterFontTypes class

Constructors

XprinterFontTypes()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

FONT_0 → const int
FONT_1 → const int
FONT_2 → const int
FONT_3 → const int
FONT_4 → const int
FONT_5 → const int
FONT_6 → const int
FONT_7 → const int
FONT_24 → const int
FONT_55 → const int