MethodChannelXprinterSdk class

An implementation of XprinterSdkPlatform that uses method channels.

Inheritance

Constructors

MethodChannelXprinterSdk()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBarcodeText() → Future<void>
override
connectDevice(String mac) → Future<bool>
override
disconnectDevice() → Future<void>
override
drawBarcode(int x, int y, XprinterBarCodeType type, int height, String data, {bool vertical = false, int? width, XprinterBarcodeRatio? ratio}) → Future<void>
override
drawBox(int x, int y, int width, int height, int thickness) → Future<void>
override
drawImage(int x, int y, Uint8List image) → Future<void>
override
drawInverseLine(int x, int y, int xend, int yend, int width) → Future<void>
override
drawLine(int x, int y, int xend, int yend, int thickness) → Future<void>
override
drawQRCode(int x, int y, String data, {XprinterQRCodeModel? codeModel, int? cellWidth}) → Future<void>
override
drawText(int x, int y, String text, {XprintFont? font, XprintRotation? rotation}) → Future<void>
override
initializePrinter({int height = 0, int offset = 0, int count = 1}) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print() → Future<void>
override
removeBarcodeText() → Future<void>
override
setAlignment(XprinterAlignment align, [int end = -1]) → Future<void>
override
setBeepLength(int length) → Future<void>
override
setMag(int width, int height) → Future<void>
override
setPageWidth(int width) → Future<void>
override
setSpeedLevel(int level) → Future<void>
override
setStringEncoding(XprinterChatset chatset) → Future<void>
override
startScanBluetooth() → Future<void>
override
stopScanBluetooth() → Future<void>
override
toString() → String
A string representation of this object.
inherited
writeCommand(Uint8List data) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

deviceScanner → Stream<List<BluetoothDevice>>
no setter